@@ -31,9 +31,17 @@
 #define max(a,b) ((a)>(b)?(a):(b))
 
 #if WITH_SDL2
+
 static SDL_Window *sdlWindow;
+
+#define USE_SDL2_RENDERER 0
+#if USE_SDL2_RENDERER
 static SDL_Renderer *sdlRenderer;
 static SDL_Texture *sdlTexture;
+#else
+static SDL_Surface *windowSurf;
+#endif
+
 #endif
 
 SDL_Surface *surf;
@@ -55,6 +63,7 @@ static void scr_sdl2_init(void)
 	sdlWindow = SDL_CreateWindow("Ballerburg SDL",
 	                             SDL_WINDOWPOS_UNDEFINED, SDL_WINDOWPOS_UNDEFINED,
 	                             640, 480, fullscreenflag);
+#if USE_SDL2_RENDERER
 	sdlRenderer = SDL_CreateRenderer(sdlWindow, -1, 0);
 	if (!sdlWindow || !sdlRenderer)
 	{
@@ -64,6 +73,9 @@ static void scr_sdl2_init(void)
 	SDL_RenderSetLogicalSize(sdlRenderer, 640, 480);
 	sdlTexture = SDL_CreateTexture(sdlRenderer, SDL_PIXELFORMAT_RGB888,
 					SDL_TEXTUREACCESS_STREAMING, 640, 480);
+#else
+	windowSurf = SDL_GetWindowSurface(sdlWindow);
+#endif
 }
 #endif
 
@@ -105,10 +117,12 @@ void scr_exit(void)
 #if WITH_SDL2
 	if (surf)
 		SDL_FreeSurface(surf);
+#if USE_SDL2_RENDERER
 	if (sdlTexture)
 		SDL_DestroyTexture(sdlTexture);
 	if (sdlRenderer)
 		SDL_DestroyRenderer(sdlRenderer);
+#endif
 	if (sdlWindow)
 		SDL_DestroyWindow(sdlWindow);
 #endif
@@ -118,9 +132,13 @@ void scr_exit(void)
 void scr_togglefullscreen(void)
 {
 #if WITH_SDL2
-	fullscreenflag ^= SDL_WINDOW_FULLSCREEN_DESKTOP;
+#if USER_SDL2_RENDERER
 	SDL_DestroyTexture(sdlTexture);
 	SDL_DestroyRenderer(sdlRenderer);
+	fullscreenflag ^= SDL_WINDOW_FULLSCREEN_DESKTOP;
+#else
+	fullscreenflag ^= SDL_WINDOW_FULLSCREEN;
+#endif
 	SDL_DestroyWindow(sdlWindow);
 	scr_sdl2_init();
 	SDL_UpdateRect(surf, 0, 0, 640, 480);
@@ -175,7 +193,7 @@ void scr_clear(void)
 	SDL_FillRect(surf, &rect, white);
 }
 
-void v_gtext(int handle, int x, int y, const char *text)
+void scr_l_text(int x, int y, const char *text)
 {
 	SDL_Rect rect;
 
@@ -212,7 +230,7 @@ void scr_ctr_text(int cx, int y, const char *text)
 	SDL_UpdateRects(surf, 1, &rect);
 }
 
-void v_circle(int handle, int x, int y, int w)
+void scr_circle(int x, int y, int w)
 {
 	SDL_Rect rect;
 
@@ -251,19 +269,19 @@ static void update_fill_color(void)
 	}
 }
 
-void vsf_style(short handle, short val)
+void scr_sf_style(short val)
 {
 	fill_style = val;
 	update_fill_color();
 }
 
-void vsf_interior(short handle, short val)
+void scr_sf_interior(short val)
 {
 	fill_interior = val;
 	update_fill_color();
 }
 
-void v_bar(short handle, short *xy)
+void scr_bar(short *xy)
 {
 	SDL_Rect rect;
 	Uint8 r, g, b;
@@ -311,7 +329,7 @@ void clr_bg(short x, short y, short w, short h)
 }
 
 
-void v_fillarea(short handle, short num, short xy[])
+void scr_fillarea(short num, short *xy)
 {
 	int i;
 	Sint16 vx[512], vy[512];
@@ -333,7 +351,7 @@ void v_fillarea(short handle, short num, short xy[])
 	SDL_UpdateRect(surf, 0,0, 640,480);
 }
 
-void v_pline(short handle, short num, short xy[])
+void scr_pline(short num, short *xy)
 {
 	int i;
 	int maxx, maxy;
@@ -516,15 +534,26 @@ void scr_restore_bg(void *ps)
 #if WITH_SDL2
 void SDL_UpdateRects(SDL_Surface *screen, int numrects, SDL_Rect *rects)
 {
+#if USE_SDL2_RENDERER
 	SDL_UpdateTexture(sdlTexture, NULL, screen->pixels, screen->pitch);
 	SDL_RenderClear(sdlRenderer);
 	SDL_RenderCopy(sdlRenderer, sdlTexture, NULL, NULL);
 	SDL_RenderPresent(sdlRenderer);
+#else
+	SDL_BlitSurface(surf, rects, windowSurf, rects);
+	SDL_UpdateWindowSurfaceRects(sdlWindow, rects, numrects);
+#endif
 }
 
 void SDL_UpdateRect(SDL_Surface *screen, Sint32 x, Sint32 y, Sint32 w, Sint32 h)
 {
-	SDL_Rect rect = { x, y, w, h };
+	SDL_Rect rect;
+	if (w == 0 && h == 0) {
+		w = 640;
+		h = 480;
+	}
+	rect.x = x; rect.y = y;
+	rect.w = w; rect.h = h;
 	SDL_UpdateRects(screen, 1, &rect);
 }
 #endif
