@@ -21,20 +21,20 @@
 
 extern SDL_Surface *surf;
 
-void v_pline(short handle, short num, short xy[]);
-void v_fillarea(short handle, short num, short xy[]);
-void v_circle(int handle, int x, int y, int w);
-void v_bar(short handle, short *xy);
-void clr(short x, short y, short w, short h);
-void clr_bg(short x, short y, short w, short h);
-void vsf_interior(short handle, short val);
-void v_gtext(int handle, int x, int y, const char *text);
-void vsf_style(short handle, short val);
-
 void scr_init(void);
 void scr_exit(void);
 void scr_togglefullscreen(void);
 void scr_clear(void);
+void scr_l_text(int x, int y, const char *text);
+void scr_ctr_text(int cx, int y, const char *text);
+void scr_circle(int x, int y, int w);
+void scr_sf_interior(short val);
+void scr_sf_style(short val);
+void scr_bar(short *xy);
+void clr(short x, short y, short w, short h);
+void clr_bg(short x, short y, short w, short h);
+void scr_fillarea(short num, short *xy);
+void scr_pline(short num, short *xy);
 void scr_line(int x1, int y1, int x2, int y2, int rgba);
 int scr_getpixel(int x, int y);
 void scr_color(int c);
@@ -42,7 +42,6 @@ void scr_fillcolor(int c);
 void color(int a);
 void scr_init_done_button(int *bx, int *by, int *bw, int *bh);
 void scr_draw_done_button(int selected);
-void scr_ctr_text(int cx, int y, const char *text);
 void scr_cannonball(int x, int y);
 void *scr_save_bg(int x, int y, int w, int h);
 void scr_restore_bg(void *ps);
