@@ -1,11 +1,16 @@
 /*
-  sdlgui.c
-
-  This file is distributed under the GNU Public License, version 2 or at
-  your option any later version. Read the file gpl.txt for details.
-
-  A tiny graphical user interface for the SDL library.
-*/
+ * sdlgui.c - A tiny graphical user interface for the SDL library.
+ *
+ * This file is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This file is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
+ * (http://www.gnu.org/licenses/) for more details.
+ */
 const char SDLGui_fileid[] = "sdlgui.c : " __DATE__ " " __TIME__;
 
 #include <SDL.h>
